\name{find_regions}
\alias{find_regions}
\title{Detection of DNA Regions Displaying Equally Directed Abnormalities}
\description{
Uses the p-values of the Wilcoxon Test for equally directed abnormalities performed by \code{edira} to detect DNA regions with particularly strong
equally directed abnormalities of two variables for a patient collective compared to a reference collective
}
\usage{
find_regions(results, chr = 1:22, resolution = 10^6, level=0.05,
   length_penalty = 4, limit=10^(-3), min_prop=0.01, min_med_num = 1,
   combine_near = 1, eliminate_short = 1, num_regions = 100, genomwide=TRUE)
}

\arguments{
  \item{results}{object returned by \code{\link{edira}}.}
  \item{chr}{chromosomes for data of which to apply the function.}
  \item{resolution}{number of consecutive position units that should be regarded as one search unit for the algorithm. With positions given in base pairs, \code{resolution = 10^6} will let the algorithm search on a MBp grid.}
  \item{level}{maximum value that p-values may have in order to be taken into account for the search.}
  \item{length_penalty}{penalty for the length of regions.}
  \item{limit}{threshold to be undercut by a minimum proportion \code{min_prop} of the p-values smaller than \code{level} in order for a region to be accepted.
  The median values must fall into the same quadrant (see \code{\link{edira}}) for the loci corresponding to these p-values.}
  \item{min_prop}{minimum proportion of the p-values in a region with respect to all p-values of the genome smaller than \code{level} which should be equal to or smaller than \code{limit} in order to accept a region.}
  \item{min_med_num}{minimum median number of data points a found region should have per search unit.}
  \item{combine_near}{minimum distance (number of search units) that different found regions should have to each other, two regions with a smaller distance to each other will be combined.}
  \item{eliminate_short}{minimum length (number of search units) found regions should have.}
  \item{num_regions}{maximum number of regions that can be found per chromosome.}
  \item{genomwide}{if \code{TRUE}, it is assumed that \code{results} includes genomwide results, i.e., not just single chromosomes or parts of chromosomes.}
}
\details{
It must be \code{limit} < \code{level}.
The default values for \code{level} and \code{limit} are sensible if differences between the loci with respect to the degree of equally directed abnormalities exist
and some notable equally directed abnormalities are present; otherwise they may have to be adjusted.
If the analysis is not genome-wide (\code{genomwide=FALSE}), the value for \code{min_prop} is adjusted based on the
length of the sequence in which the provided data points are located. For this, \code{cytoband} is used.

\code{limit} and \code{min_prop} are the central parameters to define how strong the equally directed abnormalities should be in a region to let the algorithm find it.
\code{limit} sets a threshold for the p-values and \code{min_prop} defines which proportion of the p-values has to be smallerthan this threshold.
}
\value{
A 6xc matrix where c is the number of chromosomes analyzed. Each column contains a list of results for one chromosome, while each row contains a list with information for each chromosome on:
  \item{regions_first_step}{regions found in the first step of the algorithm.}
  \item{proportions_first_step}{proportion of the p-values smaller than \code{level} which are equal to or smaller than \code{limit}, for each of the regions found in the first step of the algorithm.}
  \item{median_number_of_points_first_step}{median number of data points per search unit for each of the regions found in the first step of the algorithm.}
  \item{regions_final}{The principal results: Final list of regions found by the algorithm.}
  \item{maximum_distance_final}{maximum distance between two neighboring data points within region, for all regions contained in \code{final_regions}.}
  \item{median_number_of_points_final}{median number of data points per search unit, for all regions contained in \code{final_regions}.}
  \item{chromosome}{number of the chromosome}
}
\references{Schaefer, M., Schwender, H., Merk, S., Haferlach, C., Ickstadt, K., Dugas, M. (2009), Integrated analysis of copy number alterations and gene expression:
A bivariate assessment of equally directed abnormalities, Bioinformatics 25(24), 3228  3235.
}
\note{
The rows \code{maximum_distance} and \code{median_number_of_points} of the return object constitute additional information for the found regions, they may
be used to choose \code{length_penalty} (a high median number of points and a small maximum distance between points are desired).

Note that the region finding algorithm is an exploratory tool, it is not designed to find 'significant' regions in a formal sense.
}
\author{Martin Schaefer}
\seealso{\code{\link{edira}}, \code{\link{plot.edira}}}
\examples{
\dontrun{
data(AMLdata)
results <- edira(GE,CN_segmented,GE_ref,CN_ref_segmented)

regions <- find_regions(results, chr=5) # results just for chromosome 5

regions[4,] #show the fourth row with the list of found regions
}
}

\keyword{methods}
