\name{segmentCN}
\alias{segmentCN}
\title{Segmentation of copy number data for joint analysis with other variable}
\description{
Segments a given data set containing raw copy number intensities. For each person/sample, estimates the expected copy number intensities within the segments according to the model of Huber et al. (2006) or the CBS algorithm (Olshen et al., 2004).
Assigns to each measurement point of a second variable a copy number intensity and stores assigned copy number intensities in a new object.
}
\usage{
segmentCN(X, Y_annot, chrs = 1:22, algorithm="CBS", penalty = "BIC", maxseg = 50, estseg="mean", estval="median", sort=TRUE)
}

\arguments{ 
  \item{X}{list containing raw copy number data, to be segmented, and annotations}
  \item{Y_annot}{data frame containing annotation for another genetic variable, e.g., gene expression, which is to be integrated with the copy number data.
  At the loci provided by \code{Y_annot}, the two variables can be jointly analyzed by \code{\link{edira}}.}
  \item{chrs}{the chromosomes for data of which to apply the function.}
  \item{algorithm}{algorithm to use for estimation of breakpoints and segmented CN values. Currently, \code{algorithm="Huber"} and \code{algorithm="CBS"} are supported.}
  \item{penalty}{penalty term in likelihood approach to choose the number of segments for a chromosome, either \code{none}, \code{AIC} or \code{BIC}. Relevant only if \code{algorithm="Huber"}.}
  \item{maxseg}{maximum number of segments to try and fit per chromosome. Relevant only if \code{algorithm="Huber"}.}
  \item{estseg}{estimator for the constant copy number intensity between breakpoints used in the estimation of the segment breakpoints via the residual sum of squares criterion. Currently, \code{estseg="mean"} and \code{estseg="median"} are supported. Relevant only if \code{algorithm="Huber"}.}
  \item{estval}{estimator for the constant copy number intensity between breakpoints used to return values for further analysis. Currently, \code{estval="mean"} and \code{estval="median"} are supported. Relevant only if \code{algorithm="Huber"}.}
  \item{sort}{logical. Should the data and annotation data be sorted by a stable sorting algorithm? This sorting is necessary to produce sensible results, so \code{sort=TRUE} is mandatory if the sorting has not been done previously!}
}
\details{
\code{X} must be a list containing an object 'data' in which each column contains the data for an individual contained in this collective, and a data frame 'info'
which has a column "chromosome" containing the chromosome number and a column "position" that contains the (middle) position of each measured locus (e.g., probe set) as a single value.
\code{Y_annot} must be of the same structure than \code{X$info}, e.g., have a column "chromosome" containing the chromosome number and a column "position" that contains the (middle) position of each measured locus (e.g., probe set) as a single value.
In case of \code{Y_annot=X$info}, the segmented values will be given at the same positions as in the raw data.

IMPORTANT: The data in \code{X$data} as well as the annotation data in \code{X$info} and \code{Y_annot} must be in increasing order of (1) chromosomes and (2) positions to produce sensible results. For \code{sort=TRUE} this is done automatically.

For \code{algorithm="Huber"}, as penalty term, the BIC has been found to work better than AIC for the segmentation of copy number data (Huber et al., 2006).
}
\value{
Returns a data frame containing the estimated copy number values assigned to the loci given in \code{Y_annot}.
}
\references{
Huber, W., Toedling, J., Steinmetz, L.\ (2006), Transcript mapping with high-density oligonucleotide tiling arrays. Bioinformatics 22, 1963-1970.

Olshen, A. B., Venkatraman, E. S., Lucito, R., Wigler, M. (2004), Circular binary segmentation for the analysis of array-based DNA copy number data. Biostatistics 5, 557-572. 

Schaefer, M., Schwender, H., Merk, S., Haferlach, C., Ickstadt, K., Dugas, M. (2009), Integrated analysis of copy number alterations and gene expression:
A bivariate assessment of equally directed abnormalities, Bioinformatics 25(24), 3228  3235.
}
\note{
In the functions \code{\link{segment}} and \code{\link{costMatrix}} implemented by W. Huber in the package \code{\link{tilingArray}}, \code{estseg="mean"} and \code{estval="mean"} are used, respectively.
In Schaefer et al. (2009), \code{algorithm="Huber"} was used with \code{estval="median"} for greater robustness, together with \code{estseg="mean"}.
This functions additionally includes the option \code{estseg="median"}, which accounts for more robustness but may be considerably slower than \code{estseg="mean"}.
It calls modified versions of the \code{\link{segment}} and \code{\link{costMatrix}} functions.

The functionality of edira does not depend on any specific segmentation algorithm, as long as input matrices of equal dimensions are eventually provided as input for \code{\link{edira}}.
}
\author{Martin Schaefer}

\seealso{\code{\link{edira}}}
\examples{
\dontrun{
data(AMLdata)
CN_ref_segmented <- segmentCN(CN_ref, GE_ref$info, chr=4:7, algorithm="CBS")
}
}

\keyword{manip}
\keyword{datagen}
\keyword{methods}
